@@ -11,7 +11,7 @@ import numpy as np
 
 def plot_pop(
     poptbl, 
-    sex,
+    sex = None,
     age_range: Optional[List[int]] = None, 
     alpha: float = .5
 ):
@@ -21,12 +21,15 @@ def plot_pop(
 
     Usage
     -----
-    `plot_pop(poptbl, sex[, age_range, alpha])`
+    `plot_pop(poptbl[, sex, age_range, alpha])`
 
     Argument
     --------
     * `poptbl`: a `ProvPopTable`
-    * `sex`: an object; use only records having the same `sex` in `poptbl`.
+    * `sex`: an object, `None` by default; use only records having the same
+        `sex` in `poptbl`. If `None`, then the function checks if `poptbl`
+        has an unique `sex`. If it does, it uses that `sex`; otherwise, it
+        raises an error.
     * `age_range`: a list of two ints, `None` by default; only the records
         of `poptbl` having Ages within the closed interval defined by 
         this argument are used. If `None`, then all the Ages are used in
@@ -40,6 +43,12 @@ def plot_pop(
     pop_age = pop_groups[1]
     pop_end = poptbl.get_pop_end()
     poptbl_pop = poptbl.calculate_pop()
+    if sex is None:
+        test_uniqueness = np.unique(poptbl[pop_sex])
+        assert len(test_uniqueness) == 1, \
+            "There are more than one sex in `poptbl`. " +\
+            "Specification of `sex` argument is required."
+        sex = test_uniqueness[0]
     if age_range is not None:
         poptbl_pop = poptbl_pop\
             .loc[lambda df: df[pop_age] <= age_range[1]]\
